@@ -2,16 +2,12 @@
 
 import sys, os, re
 
-# If your extensions are in another directory, add it here. If the directory
-# is relative to the documentation root, use os.path.abspath to make it
-# absolute, like shown here.
-sys.path.insert(0, os.path.abspath('../sphinxext'))
-
 # Check Sphinx version
 import sphinx
-if sphinx.__version__ < "0.5":
-    raise RuntimeError("Sphinx 0.5.dev or newer required")
+if sphinx.__version__ < "1.0.1":
+    raise RuntimeError("Sphinx 1.0.1 or newer required")
 
+needs_sphinx = '1.0'
 
 # -----------------------------------------------------------------------------
 # General configuration
@@ -19,15 +15,29 @@ if sphinx.__version__ < "0.5":
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
+
+sys.path.insert(0, os.path.abspath('../sphinxext'))
+
 extensions = ['sphinx.ext.autodoc', 'sphinx.ext.pngmath', 'numpydoc',
-              'sphinx.ext.intersphinx', 'sphinx.ext.coverage', 'plot_directive']
+              'sphinx.ext.intersphinx', 'sphinx.ext.coverage',
+              'sphinx.ext.autosummary']
 
-if sphinx.__version__ >= "0.7":
-    extensions.append('sphinx.ext.autosummary')
+# Determine if the matplotlib has a recent enough version of the
+# plot_directive.
+try:
+    from matplotlib.sphinxext import plot_directive
+except ImportError:
+    use_matplotlib_plot_directive = False
 else:
-    extensions.append('autosummary')
-    extensions.append('only_directives')
+    try:
+        use_matplotlib_plot_directive = (plot_directive.__version__ >= 2)
+    except AttributeError:
+        use_matplotlib_plot_directive = False
 
+if use_matplotlib_plot_directive:
+    extensions.append('matplotlib.sphinxext.plot_directive')
+else:
+    raise RuntimeError("You need a recent enough version of matplotlib")
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -136,7 +146,7 @@ html_additional_pages = {}
 html_use_modindex = True
 
 # If true, the reST sources are included in the HTML build as _sources/<name>.
-#html_copy_source = True
+html_copy_source = False
 
 # If true, an OpenSearch description file will be output, and all pages will
 # contain a <link> tag referring to it.  The value of this option must be the
@@ -183,21 +193,33 @@ latex_documents = [
 # Additional stuff for the LaTeX preamble.
 latex_preamble = r'''
 \usepackage{amsmath}
+
 \DeclareUnicodeCharacter{00A0}{\nobreakspace}
 
-% In the parameters section, place a newline after the Parameters
-% header
+% In the parameters etc. sections, align uniformly, and adjust label emphasis
 \usepackage{expdlist}
 \let\latexdescription=\description
-\def\description{\latexdescription{}{} \breaklabel}
+\let\endlatexdescription=\enddescription
+\renewenvironment{description}%
+{\begin{latexdescription}[\setleftmargin{60pt}\breaklabel\setlabelstyle{\bfseries\itshape}]}%
+{\end{latexdescription}}
 
 % Make Examples/etc section headers smaller and more compact
 \makeatletter
-\titleformat{\paragraph}{\normalsize\py@HeaderFamily}%
-            {\py@TitleColor}{0em}{\py@TitleColor}{\py@NormalColor}
+\titleformat{\paragraph}{\normalsize\normalfont\bfseries\itshape}%
+            {\py@NormalColor}{0em}{\py@NormalColor}{\py@NormalColor}
 \titlespacing*{\paragraph}{0pt}{1ex}{0pt}
 \makeatother
 
+% Save vertical space in parameter lists and elsewhere
+\makeatletter
+\renewenvironment{quote}%
+               {\list{}{\topsep=0pt%
+                        \parsep \z@ \@plus\p@}%
+                \item\relax}%
+               {\endlist}
+\makeatother
+
 % Fix footer/header
 \renewcommand{\chaptermark}[1]{\markboth{\MakeUppercase{\thechapter.\ #1}}{}}
 \renewcommand{\sectionmark}[1]{\markright{\MakeUppercase{\thesection.\ #1}}}
@@ -226,8 +248,8 @@ intersphinx_mapping = {
 # If we want to do a phantom import from an XML file for all autodocs
 phantom_import_file = 'dump.xml'
 
-# Edit links
-#numpydoc_edit_link = '`Edit </pydocweb/doc/%(full_name)s/>`__'
+# Generate plots for example sections
+numpydoc_use_plots = True
 
 # -----------------------------------------------------------------------------
 # Autosummary
@@ -264,12 +286,12 @@ np.random.seed(123)
 """
 plot_include_source = True
 plot_formats = [('png', 100), 'pdf']
+plot_html_show_formats = False
 
 import math
 phi = (math.sqrt(5) + 1)/2
 
-import matplotlib
-matplotlib.rcParams.update({
+plot_rcparams = {
     'font.size': 8,
     'axes.titlesize': 8,
     'axes.labelsize': 8,
@@ -283,4 +305,77 @@ matplotlib.rcParams.update({
     'figure.subplot.top': 0.85,
     'figure.subplot.wspace': 0.4,
     'text.usetex': False,
-})
+}
+
+if not use_matplotlib_plot_directive:
+    import matplotlib
+    matplotlib.rcParams.update(plot_rcparams)
+
+# -----------------------------------------------------------------------------
+# Source code links
+# -----------------------------------------------------------------------------
+
+import inspect
+from os.path import relpath, dirname
+
+for name in ['sphinx.ext.linkcode', 'linkcode', 'numpydoc.linkcode']:
+    try:
+        __import__(name)
+        extensions.append(name)
+        break
+    except ImportError:
+        pass
+else:
+    print "NOTE: linkcode extension not found -- no links to source generated"
+
+def linkcode_resolve(domain, info):
+    """
+    Determine the URL corresponding to Python object
+    """
+    if domain != 'py':
+        return None
+
+    modname = info['module']
+    fullname = info['fullname']
+
+    submod = sys.modules.get(modname)
+    if submod is None:
+        return None
+
+    obj = submod
+    for part in fullname.split('.'):
+        try:
+            obj = getattr(obj, part)
+        except:
+            return None
+
+    try:
+        fn = inspect.getsourcefile(obj)
+    except:
+        fn = None
+    if not fn:
+        try:
+            fn = inspect.getsourcefile(sys.modules[obj.__module__])
+        except:
+            fn = None
+    if not fn:
+        return None
+
+    try:
+        source, lineno = inspect.findsource(obj)
+    except:
+        lineno = None
+
+    if lineno:
+        linespec = "#L%d" % (lineno + 1)
+    else:
+        linespec = ""
+
+    fn = relpath(fn, start=dirname(scipy.__file__))
+
+    if 'dev' in scipy.__version__:
+        return "http://github.com/scipy/scipy/blob/master/scipy/%s%s" % (
+           fn, linespec)
+    else:
+        return "http://github.com/scipy/scipy/blob/v%s/scipy/%s%s" % (
+           scipy.__version__, fn, linespec)
