@@ -1,9 +1,12 @@
 #!/usr/bin/env python
 # Created by John Travers, Robert Hetland, 2007
 """ Test functions for rbf module """
+from __future__ import division, print_function, absolute_import
+
 
 import numpy as np
-from numpy.testing import assert_, assert_array_almost_equal, assert_almost_equal
+from numpy.testing import (assert_, assert_array_almost_equal,
+                           assert_almost_equal, run_module_suite)
 from numpy import linspace, sin, random, exp, allclose
 from scipy.interpolate.rbf import Rbf
 
@@ -100,7 +103,6 @@ def test_default_construction():
     yi = rbf(x)
     assert_array_almost_equal(y, yi)
 
-
 def test_function_is_callable():
     """Check that the Rbf class can be constructed with function=callable."""
     x = linspace(0,10,9)
@@ -109,3 +111,24 @@ def test_function_is_callable():
     rbf = Rbf(x, y, function=linfunc)
     yi = rbf(x)
     assert_array_almost_equal(y, yi)
+
+def test_two_arg_function_is_callable():
+    """Check that the Rbf class can be constructed with a two argument
+    function=callable."""
+    def _func(self, r):
+        return self.epsilon + r
+
+    x = linspace(0,10,9)
+    y = sin(x)
+    rbf = Rbf(x, y, function=_func)
+    yi = rbf(x)
+    assert_array_almost_equal(y, yi)
+
+def test_rbf_epsilon_none():
+    x = linspace(0, 10, 9)
+    y = sin(x)
+    rbf = Rbf(x, y, epsilon=None)
+
+
+if __name__ == "__main__":
+    run_module_suite()
