@@ -1,3 +1,5 @@
+from __future__ import division, print_function, absolute_import
+
 from scipy import *
 from scipy.sparse.linalg import lobpcg
 from symeig import symeig
@@ -32,7 +34,7 @@ data1=[]
 data2=[]
 
 for n in N:
-    print '******', n
+    print('******', n)
     A,B = test(n) # Mikota pair
     X = rand(n,m)
     X = linalg.orth(X)
@@ -43,18 +45,18 @@ for n in N:
                               residualTolerance = 1e-4, maxIterations = 40)
     data1.append(time.clock()-tt)
     eigs = sort(eigs)
-    print
-    print 'Results by LOBPCG'
-    print
-    print n,eigs
+    print()
+    print('Results by LOBPCG')
+    print()
+    print(n,eigs)
 
     tt = time.clock()
     w,v=symeig(A,B,range=(1,m))
     data2.append(time.clock()-tt)
-    print
-    print 'Results by symeig'
-    print
-    print n, w
+    print()
+    print('Results by symeig')
+    print()
+    print(n, w)
 
 xlabel(r'Size $n$')
 ylabel(r'Elapsed time $t$')
