@@ -1,6 +1,7 @@
 """
 Tests for the stats.mstats module (support for maskd arrays)
 """
+from __future__ import division, print_function, absolute_import
 
 
 import numpy as np
@@ -9,33 +10,32 @@ import numpy.ma as ma
 from numpy.ma import masked, nomask
 
 import scipy.stats.mstats as mstats
-from numpy.testing import *
+from scipy import stats
+from numpy.testing import TestCase, run_module_suite
 from numpy.ma.testutils import assert_equal, assert_almost_equal, \
-    assert_array_almost_equal
-
+    assert_array_almost_equal, assert_array_almost_equal_nulp, assert_
 
 
 class TestMquantiles(TestCase):
-    """Regression tests for mstats module.""" 
-    def test_mquantiles_limit_keyword(self): 
-        """Ticket #867""" 
-        data = np.array([[   6.,    7.,    1.], 
-                         [  47.,   15.,    2.], 
-                         [  49.,   36.,    3.], 
-                         [  15.,   39.,    4.], 
-                         [  42.,   40., -999.], 
-                         [  41.,   41., -999.], 
-                         [   7., -999., -999.], 
-                         [  39., -999., -999.], 
-                         [  43., -999., -999.], 
-                         [  40., -999., -999.], 
+    """Regression tests for mstats module."""
+    def test_mquantiles_limit_keyword(self):
+        """Ticket #867"""
+        data = np.array([[   6.,    7.,    1.],
+                         [  47.,   15.,    2.],
+                         [  49.,   36.,    3.],
+                         [  15.,   39.,    4.],
+                         [  42.,   40., -999.],
+                         [  41.,   41., -999.],
+                         [   7., -999., -999.],
+                         [  39., -999., -999.],
+                         [  43., -999., -999.],
+                         [  40., -999., -999.],
                          [  36., -999., -999.]])
-        desired = [[19.2, 14.6, 1.45], 
-                   [40.0, 37.5, 2.5 ], 
-                   [42.8, 40.05, 3.55]] 
-        quants = mstats.mquantiles(data, axis=0, limit=(0, 50)) 
-        assert_almost_equal(quants, desired) 
-
+        desired = [[19.2, 14.6, 1.45],
+                   [40.0, 37.5, 2.5 ],
+                   [42.8, 40.05, 3.55]]
+        quants = mstats.mquantiles(data, axis=0, limit=(0, 50))
+        assert_almost_equal(quants, desired)
 
 
 class TestGMean(TestCase):
@@ -47,7 +47,7 @@ class TestGMean(TestCase):
 
         desired1 = mstats.gmean(a,axis=-1)
         assert_almost_equal(actual, desired1, decimal=14)
-        assert not isinstance(desired1, ma.MaskedArray)
+        assert_(not isinstance(desired1, ma.MaskedArray))
         #
         a = ma.array((1,2,3,4),mask=(0,0,0,1))
         actual= mstats.gmean(a)
@@ -73,6 +73,7 @@ class TestGMean(TestCase):
                             np.power(1*4,1./2.)))
         assert_array_almost_equal(actual, desired, decimal=14)
 
+
 class TestHMean(TestCase):
     def test_1D(self):
         a = (1,2,3,4)
@@ -129,13 +130,17 @@ class TestCorr(TestCase):
     def test_pearsonr(self):
         "Tests some computations of Pearson's r"
         x = ma.arange(10)
-        assert_almost_equal(mstats.pearsonr(x,x)[0], 1.0)
-        assert_almost_equal(mstats.pearsonr(x,x[::-1])[0], -1.0)
-        #
-        x = ma.array(x, mask=True)
-        pr = mstats.pearsonr(x,x)
-        assert(pr[0] is masked)
-        assert(pr[1] is masked)
+        olderr = np.seterr(all='ignore')
+        try:
+            assert_almost_equal(mstats.pearsonr(x,x)[0], 1.0)
+            assert_almost_equal(mstats.pearsonr(x,x[::-1])[0], -1.0)
+
+            x = ma.array(x, mask=True)
+            pr = mstats.pearsonr(x,x)
+        finally:
+            np.seterr(**olderr)
+        assert_(pr[0] is masked)
+        assert_(pr[1] is masked)
     #
     def test_spearmanr(self):
         "Tests some computations of Spearman's rho"
@@ -194,34 +199,6 @@ class TestCorr(TestCase):
              2.8,2.8,2.5,2.4,2.3,2.1,1.7,1.7,1.5,1.3,1.3,1.2,1.2,1.1,
              0.8,0.7,0.6,0.5,0.2,0.2,0.1,np.nan]
         assert_almost_equal(mstats.pointbiserialr(x, y)[0], 0.36149, 5)
-    #
-    def test_cov(self):
-        "Tests the cov function."
-        x = ma.array([[1,2,3],[4,5,6]], mask=[[1,0,0],[0,0,0]])
-        c = mstats.cov(x[0])
-        assert_equal(c, x[0].var(ddof=1))
-        c = mstats.cov(x[1])
-        assert_equal(c, x[1].var(ddof=1))
-        c = mstats.cov(x)
-        assert_equal(c[1,0], (x[0].anom()*x[1].anom()).sum())
-        #
-        x = [[nan,nan,  4,  2, 16, 26,  5,  1,  5,  1,  2,  3,  1],
-             [  4,  3,  5,  3,  2,  7,  3,  1,  1,  2,  3,  5,  3],
-             [  3,  2,  5,  6, 18,  4,  9,  1,  1,nan,  1,  1,nan],
-             [nan,  6, 11,  4, 17,nan,  6,  1,  1,  2,  5,  1,  1]]
-        x = ma.fix_invalid(x).T
-        (winter,spring,summer,fall) = x.T
-        #
-        assert_almost_equal(mstats.cov(winter,winter,bias=True),
-                            winter.var(ddof=0))
-        assert_almost_equal(mstats.cov(winter,winter,bias=False),
-                            winter.var(ddof=1))
-        assert_almost_equal(mstats.cov(winter,spring)[0,1], 7.7)
-        assert_almost_equal(mstats.cov(winter,spring)[1,0], 7.7)
-        assert_almost_equal(mstats.cov(winter,summer)[0,1], 19.1111111, 7)
-        assert_almost_equal(mstats.cov(winter,summer)[1,0], 19.1111111, 7)
-        assert_almost_equal(mstats.cov(winter,fall)[0,1], 20)
-        assert_almost_equal(mstats.cov(winter,fall)[1,0], 20)
 
 
 class TestTrimming(TestCase):
@@ -302,21 +279,30 @@ class TestTrimming(TestCase):
 
 
 class TestMoments(TestCase):
-    """
-        Comparison numbers are found using R v.1.5.1
-        note that length(testcase) = 4
-        testmathworks comes from documentation for the
-        Statistics Toolbox for Matlab and can be found at both
-        http://www.mathworks.com/access/helpdesk/help/toolbox/stats/kurtosis.shtml
-        http://www.mathworks.com/access/helpdesk/help/toolbox/stats/skewness.shtml
-        Note that both test cases came from here.
-    """
+    # Comparison numbers are found using R v.1.5.1
+    # note that length(testcase) = 4
+    # testmathworks comes from documentation for the
+    # Statistics Toolbox for Matlab and can be found at both
+    # http://www.mathworks.com/access/helpdesk/help/toolbox/stats/kurtosis.shtml
+    # http://www.mathworks.com/access/helpdesk/help/toolbox/stats/skewness.shtml
+    # Note that both test cases came from here.
     testcase = [1,2,3,4]
     testmathworks = ma.fix_invalid([1.165 , 0.6268, 0.0751, 0.3516, -0.6965,
                                     np.nan])
+    testcase_2d = ma.array(
+    np.array([[ 0.05245846,  0.50344235,  0.86589117,  0.36936353,  0.46961149],
+           [ 0.11574073,  0.31299969,  0.45925772,  0.72618805,  0.75194407],
+           [ 0.67696689,  0.91878127,  0.09769044,  0.04645137,  0.37615733],
+           [ 0.05903624,  0.29908861,  0.34088298,  0.66216337,  0.83160998],
+           [ 0.64619526,  0.94894632,  0.27855892,  0.0706151 ,  0.39962917]]),
+    mask = np.array([[ True, False, False,  True, False],
+           [ True,  True,  True, False,  True],
+           [False, False, False, False, False],
+           [True, True, True, True, True],
+           [False, False,  True, False, False]], dtype=np.bool))
+
     def test_moment(self):
-        """
-        mean((testcase-mean(testcase))**power,axis=0),axis=0))**power))"""
+        # mean((testcase-mean(testcase))**power,axis=0),axis=0))**power))
         y = mstats.moment(self.testcase,1)
         assert_almost_equal(y,0.0,10)
         y = mstats.moment(self.testcase,2)
@@ -325,17 +311,16 @@ class TestMoments(TestCase):
         assert_almost_equal(y,0.0)
         y = mstats.moment(self.testcase,4)
         assert_almost_equal(y,2.5625)
+
     def test_variation(self):
-        """variation = samplestd/mean """
+        #variation = samplestd/mean
 ##        y = stats.variation(self.shoes[0])
 ##        assert_almost_equal(y,21.8770668)
         y = mstats.variation(self.testcase)
         assert_almost_equal(y,0.44721359549996, 10)
 
     def test_skewness(self):
-        """
-            sum((testmathworks-mean(testmathworks,axis=0))**3,axis=0)/((sqrt(var(testmathworks)*4/5))**3)/5
-        """
+        # sum((testmathworks-mean(testmathworks,axis=0))**3,axis=0)/((sqrt(var(testmathworks)*4/5))**3)/5
         y = mstats.skew(self.testmathworks)
         assert_almost_equal(y,-0.29322304336607,10)
         y = mstats.skew(self.testmathworks,bias=0)
@@ -344,26 +329,46 @@ class TestMoments(TestCase):
         assert_almost_equal(y,0.0,10)
 
     def test_kurtosis(self):
-        """
-            sum((testcase-mean(testcase,axis=0))**4,axis=0)/((sqrt(var(testcase)*3/4))**4)/4
-            sum((test2-mean(testmathworks,axis=0))**4,axis=0)/((sqrt(var(testmathworks)*4/5))**4)/5
-            Set flags for axis = 0 and
-            fisher=0 (Pearson's definition of kurtosis for compatibility with Matlab)
-        """
+        #    sum((testcase-mean(testcase,axis=0))**4,axis=0)/((sqrt(var(testcase)*3/4))**4)/4
+        #    sum((test2-mean(testmathworks,axis=0))**4,axis=0)/((sqrt(var(testmathworks)*4/5))**4)/5
+        #    Set flags for axis = 0 and
+        #    fisher=0 (Pearson's definition of kurtosis for compatibility with Matlab)
         y = mstats.kurtosis(self.testmathworks,0,fisher=0,bias=1)
         assert_almost_equal(y, 2.1658856802973,10)
         # Note that MATLAB has confusing docs for the following case
         #  kurtosis(x,0) gives an unbiased estimate of Pearson's skewness
         #  kurtosis(x)  gives a biased estimate of Fisher's skewness (Pearson-3)
         #  The MATLAB docs imply that both should give Fisher's
-        y = mstats.kurtosis(self.testmathworks,fisher=0,bias=0)
+        y = mstats.kurtosis(self.testmathworks,fisher=0, bias=0)
         assert_almost_equal(y, 3.663542721189047,10)
         y = mstats.kurtosis(self.testcase,0,0)
         assert_almost_equal(y,1.64)
-    #
+
+        # test that kurtosis works on multidimensional masked arrays
+        correct_2d = ma.array(np.array([-1.5, -3., -1.47247052385,  0.,
+                                        -1.26979517952]),
+                              mask=np.array([False, False, False,  True,
+                                             False], dtype=np.bool))
+        assert_array_almost_equal(mstats.kurtosis(self.testcase_2d, 1),
+                                  correct_2d)
+        for i, row in enumerate(self.testcase_2d):
+            assert_almost_equal(mstats.kurtosis(row), correct_2d[i])
+
+        correct_2d_bias_corrected = ma.array(
+            np.array([-1.5, -3., -1.88988209538,  0., -0.5234638463918877]),
+            mask=np.array([False, False, False,  True, False], dtype=np.bool))
+        assert_array_almost_equal(mstats.kurtosis(self.testcase_2d, 1,
+                                                  bias=False),
+                                  correct_2d_bias_corrected)
+        for i, row in enumerate(self.testcase_2d):
+            assert_almost_equal(mstats.kurtosis(row, bias=False),
+                                correct_2d_bias_corrected[i])
+
+        # Check consistency between stats and mstats implementations
+        assert_array_almost_equal_nulp(mstats.kurtosis(self.testcase_2d[2, :]),
+                                       stats.kurtosis(self.testcase_2d[2, :]))
+
     def test_mode(self):
-        "Tests the mode"
-        #
         a1 = [0,0,0,1,1,1,2,3,3,3,3,4,5,6,7]
         a2 = np.reshape(a1, (3,5))
         ma1 = ma.masked_where(ma.array(a1)>2,a1)
@@ -404,34 +409,6 @@ class TestVariability(TestCase):
          note that length(testcase) = 4
     """
     testcase = ma.fix_invalid([1,2,3,4,np.nan])
-    #
-    def test_std(self):
-        y = mstats.std(self.testcase)
-        assert_almost_equal(y,1.290994449)
-
-    def test_var(self):
-        """
-        var(testcase) = 1.666666667 """
-        #y = stats.var(self.shoes[0])
-        #assert_approx_equal(y,6.009)
-        y = mstats.var(self.testcase)
-        assert_almost_equal(y,1.666666667)
-
-    def test_samplevar(self):
-        """
-        R does not have 'samplevar' so the following was used
-        var(testcase)*(4-1)/4  where 4 = length(testcase)
-        """
-        #y = stats.samplevar(self.shoes[0])
-        #assert_approx_equal(y,5.4081)
-        y = mstats.samplevar(self.testcase)
-        assert_almost_equal(y,1.25)
-
-    def test_samplestd(self):
-        #y = stats.samplestd(self.shoes[0])
-        #assert_approx_equal(y,2.325532197)
-        y = mstats.samplestd(self.testcase)
-        assert_almost_equal(y,1.118033989)
 
     def test_signaltonoise(self):
         """
@@ -442,16 +419,6 @@ class TestVariability(TestCase):
         y = mstats.signaltonoise(self.testcase)
         assert_almost_equal(y,2.236067977)
 
-    def test_stderr(self):
-        """
-        this is not in R, so used
-        sqrt(var(testcase))/sqrt(4)
-        """
-##        y = stats.stderr(self.shoes[0])
-##        assert_approx_equal(y,0.775177399)
-        y = mstats.stderr(self.testcase)
-        assert_almost_equal(y,0.6454972244)
-
     def test_sem(self):
         """
         this is not in R, so used
@@ -462,24 +429,26 @@ class TestVariability(TestCase):
         y = mstats.sem(self.testcase)
         assert_almost_equal(y,0.6454972244)
 
-    def test_z(self):
-        """
-        not in R, so used
-        (10-mean(testcase,axis=0))/sqrt(var(testcase)*3/4)
-        """
-        y = mstats.z(self.testcase, ma.array(self.testcase).mean())
-        assert_almost_equal(y,0.0)
-
-    def test_zs(self):
+    def test_zmap(self):
         """
         not in R, so tested by using
         (testcase[i]-mean(testcase,axis=0))/sqrt(var(testcase)*3/4)
         """
-        y = mstats.zs(self.testcase)
+        y = mstats.zmap(self.testcase, self.testcase)
+        desired_unmaskedvals = ([-1.3416407864999, -0.44721359549996 ,
+                                 0.44721359549996 , 1.3416407864999])
+        assert_array_almost_equal(desired_unmaskedvals,
+                                  y.data[y.mask==False], decimal=12)
+
+    def test_zscore(self):
+        """
+        not in R, so tested by using
+        (testcase[i]-mean(testcase,axis=0))/sqrt(var(testcase)*3/4)
+        """
+        y = mstats.zscore(self.testcase)
         desired = ma.fix_invalid([-1.3416407864999, -0.44721359549996 ,
                                   0.44721359549996 , 1.3416407864999, np.nan])
-        assert_almost_equal(desired,y,decimal=12)
-
+        assert_almost_equal(desired, y, decimal=12)
 
 
 class TestMisc(TestCase):
@@ -529,5 +498,22 @@ class TestMisc(TestCase):
         assert_almost_equal(result[1], 0.5692, 4)
 
 
+def test_regress_simple():
+    """Regress a line with sinusoidal noise. Test for #1273."""
+    x = np.linspace(0, 100, 100)
+    y = 0.2 * np.linspace(0, 100, 100) + 10
+    y += np.sin(np.linspace(0, 20, 100))
+
+    slope, intercept, r_value, p_value, sterr = mstats.linregress(x, y)
+    assert_almost_equal(slope, 0.19644990055858422)
+    assert_almost_equal(intercept, 10.211269918932341)
+
+
+def test_plotting_positions():
+    """Regression test for #1256"""
+    pos = mstats.plotting_positions(np.arange(3), 0, 0)
+    assert_array_almost_equal(pos.data, np.array([0.25, 0.5, 0.75]))
+
+
 if __name__ == "__main__":
     run_module_suite()
